@@ -14,6 +14,7 @@ use anyhow::Result;
 use chrono::Local;
 use indicatif::ProgressBar;
 use log::*;
+use pariter::{scope, IteratorExt};
 
 use crate::backend::{DecryptWriteBackend, ReadSource, ReadSourceEntry};
 use crate::blob::BlobType;
@@ -59,13 +60,18 @@ impl<BE: DecryptWriteBackend, I: IndexedBackend> Archiver<BE, I> {
         })
     }
 
-    pub fn archive(
+    pub fn archive<R>(
         mut self,
-        src: impl ReadSource,
+        src: R,
         backup_path: &Path,
         as_path: Option<&PathBuf>,
         p: &ProgressBar,
-    ) -> Result<SnapshotFile> {
+    ) -> Result<SnapshotFile>
+    where
+        R: ReadSource + 'static,
+        <R as ReadSource>::Open: Send,
+        <R as ReadSource>::Iter: Send,
+    {
         if !p.is_hidden() {
             if let Some(size) = src.size()? {
                 p.set_length(size);
@@ -104,28 +110,28 @@ impl<BE: DecryptWriteBackend, I: IndexedBackend> Archiver<BE, I> {
         // handle beginning and ending of trees
         let iter = TreeIterator::new(iter);
 
-        // use parent snapshot
-        let iter = iter.filter_map(|item| match self.parent.process(item) {
-            Ok(item) => Some(item),
-            Err(err) => {
-                warn!("ignoring error reading parent snapshot: {err:?}");
-                None
-            }
-        });
-
-        // archive files
-        let iter = iter.filter_map(|item| match self.file_archiver.process(item, p.clone()) {
-            Ok(item) => Some(item),
-            Err(err) => {
-                warn!("ignoring error: {err:?}");
-                None
-            }
-        });
-
-        // save items in trees
-        for item in iter {
-            self.tree_archiver.add(item)?;
-        }
+        scope(|scope| -> Result<_> {
+            // use parent snapshot
+            iter.filter_map(|item| match self.parent.process(item) {
+                Ok(item) => Some(item),
+                Err(err) => {
+                    warn!("ignoring error reading parent snapshot: {err:?}");
+                    None
+                }
+            })
+            // archive files in parallel
+            .parallel_map_scoped(scope, |item| self.file_archiver.process(item, p.clone()))
+            .readahead_scoped(scope)
+            .filter_map(|item| match item {
+                Ok(item) => Some(item),
+                Err(err) => {
+                    warn!("ignoring error: {err:?}");
+                    None
+                }
+            })
+            .try_for_each(|item| self.tree_archiver.add(item))
+        })
+        .unwrap()?;
 
         let stats = self.file_archiver.finalize()?;
         let (id, mut summary) = self.tree_archiver.finalize(self.parent_tree)?;
