@@ -50,20 +50,20 @@ struct Args {
 }
 
 #[serde_as]
-#[derive(Default, Parser, Deserialize, Merge)]
+#[derive(Default, Debug, Parser, Deserialize, Merge)]
 #[serde(default, rename_all = "kebab-case", deny_unknown_fields)]
 pub struct GlobalOpts {
     /// Config profile to use. This parses the file `<PROFILE>.toml` in the config directory.
+    /// [default: "rustic"]
     #[clap(
         short = 'P',
         long,
         global = true,
         value_name = "PROFILE",
-        default_value = "rustic",
         env = "RUSTIC_USE_PROFILE"
     )]
-    #[merge(skip)]
-    use_profile: String,
+    #[merge(strategy = merge::vec::append)]
+    use_profile: Vec<String>,
 
     /// Only show what would be done without modifying anything. Does not affect read-only commands
     #[clap(long, short = 'n', global = true, env = "RUSTIC_DRY_RUN")]
@@ -145,6 +145,9 @@ enum Command {
     /// Show a detailed overview of the snapshots within the repository
     Snapshots(snapshots::Opts),
 
+    /// Show the configuration which has been read from the config file(s)
+    ShowConfig,
+
     /// Update to the latest rustic release
     SelfUpdate(self_update::Opts),
 
@@ -168,10 +171,19 @@ pub fn execute() -> Result<()> {
     let command: Vec<_> = std::env::args_os().collect();
     let args = Args::parse_from(&command);
     let mut config = args.config;
+    if config.global.use_profile.is_empty() {
+        config.global.use_profile.push("rustic".to_string());
+    }
 
     // get global options from command line / env and config file
-    let profile = config.global.use_profile.clone();
-    config.merge_profile(&profile)?;
+    for profile in &config.global.use_profile.clone() {
+        config.merge_profile(profile)?;
+    }
+
+    if let Command::ShowConfig = args.command {
+        println!("{config:#?}");
+        return Ok(());
+    }
 
     // start logger
     let level_filter = config.global.log_level.unwrap_or(LevelFilter::Info);
@@ -255,6 +267,7 @@ pub fn execute() -> Result<()> {
         Command::Merge(opts) => merge_cmd::execute(repo, config, opts, command)?,
         Command::SelfUpdate(_) => {} // already handled above
         Command::Snapshots(opts) => snapshots::execute(repo, config, opts)?,
+        Command::ShowConfig => {} // already handled above
         Command::Prune(opts) => prune::execute(repo, config, opts, vec![])?,
         Command::Restore(opts) => restore::execute(repo, config, opts)?,
         Command::Repair(opts) => repair::execute(repo, config, opts)?,
